@@ -86,7 +86,7 @@
 #define KCMUTILS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCMUTILS_NO_DEPRECATED
-#  define KCMUTILS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55100
+#  define KCMUTILS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55200
 #endif
 #ifdef KCMUTILS_NO_DEPRECATED_WARNINGS
 #  define KCMUTILS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KCMUTILS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCMUTILS_DEPRECATED_WARNINGS_SINCE KCMUTILS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCMUTILS_DEPRECATED_WARNINGS_SINCE 0x55100
+#    define KCMUTILS_DEPRECATED_WARNINGS_SINCE 0x55200
 #  endif
 #endif
 
@@ -121,8 +121,21 @@
 #else
 #  define KCMUTILS_DEPRECATED_VERSION_5_76(text)
 #endif
+
+#if KCMUTILS_DEPRECATED_WARNINGS_SINCE >= 0x55200
+#  define KCMUTILS_DEPRECATED_VERSION_5_82(text) KCMUTILS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCMUTILS_DEPRECATED_VERSION_5_82(text)
+#endif
 #define KCMUTILS_DEPRECATED_VERSION_5(minor, text)      KCMUTILS_DEPRECATED_VERSION_5_##minor(text)
 #define KCMUTILS_DEPRECATED_VERSION(major, minor, text) KCMUTILS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KCMUTILS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCMUTILS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
+#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
+#  define KCMUTILS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KCMUTILS_DEPRECATED_VERSION(major, minor, text)
+#  define KCMUTILS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCMUTILS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#else
+#  define KCMUTILS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
+#  define KCMUTILS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#endif
 
 #endif /* KCMUTILS_EXPORT_H */
